==> JVPC-0.93.zip: JVPC-0.93/vga/RstGen.java <==
// File: RstGen.java

package jvpc.vga;

import java.util.Hashtable;
import java.io.*;

/**
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     7 III 1999
 * @version   7 III 1999
 */
public class RstGen
  extends Generator
{
  int shippointer,targetpointer;
  int pdatapointer,bdatapointer;
  int mdatapointer,shipxypointer;
  int genpointer,vcrpointer;

  public RstGen(InputStream is) throws IOException {
    super(is);
    shippointer=source.readInt()-1;
    targetpointer=source.readInt()-1;
    pdatapointer=source.readInt()-1;
    bdatapointer=source.readInt()-1;
    mdatapointer=source.readInt()-1;
    shipxypointer=source.readInt()-1;
    genpointer=source.readInt()-1;
    vcrpointer=source.readInt()-1;
    //report("pointers are: "+shippointer+" "+targetpointer+" "+pdatapointer+
    //   " "+bdatapointer+" "+mdatapointer+" "+shipxypointer+" "+genpointer+
    //   " "+vcrpointer);
  }

  public int getTurnNumber() throws IOException {
    // source.mark(123456789); // never saw a result that big
    source.skipUntil(genpointer);
    source.skip(140);
    int turnnr=source.readShort();
    // source.reset(); // mark() not supported (jdk 1.1.6)
    return turnnr;
  }

  public void generateAll(Universe u,int player) throws IOException {
    // read ships
    source.skipUntil(shippointer);
    ShipGen shipgen=new ShipGen(this);
    shipgen.generateAll(u);
    u.shipgen[player]=shipgen;
    // read targets
    source.skipUntil(targetpointer);
    TargetGen targetgen=new TargetGen(this);
    targetgen.generateAll(u,player);
    // read pdatas
    source.skipUntil(pdatapointer);
    PDataGen pdatagen=new PDataGen(this);
    pdatagen.generateAll(u,player);
    u.pdatagen[player]=pdatagen;
    // read bdatas
    source.skipUntil(bdatapointer);
    BDataGen bdatagen=new BDataGen(this);
    bdatagen.generateAll(u);
    //u.bdatagen[player]=bdatagen;
    // read mdatas
    source.skipUntil(mdatapointer);
    MDataGen mdatagen=new MDataGen(this);
    mdatagen.generateAll(u,player,mdatapointer);
    // read shipxys
    source.skipUntil(shipxypointer);
    ShipXYGen shipxygen=new ShipXYGen(this);
    shipxygen.generateAll(u);
    // read gens
    source.skipUntil(genpointer);
    GenGen gengen=new GenGen(this,player,false);
    u.putGen(gengen.generate(),player);
    // read vcrs
    source.skipUntil(vcrpointer);
    VcrGen vcrgen=new VcrGen(this);
    vcrgen.generateAll(u);

    // 'coz a FileStream doesn't have a reference to the File (name),
    // the workaround is getLastOpenedFile() -- very dirty, Kero.
    copyFileToDir(InputFileOpener.getLastOpenedFile().getAbsolutePath(), u.game.workdir.toString()+u.getTurnNumber());
  }
}

==> JVPC-0.94.zip: JVPC-0.94/vga/RstGen.java <==
// File: RstGen.java

package jvpc.vga;

import java.util.Hashtable;
import java.io.*;

/**
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     7 III 1999
 * @version   7 III 1999
 */
public class RstGen
  extends Generator
{
  int shippointer,targetpointer;
  int pdatapointer,bdatapointer;
  int mdatapointer,shipxypointer;
  int genpointer,vcrpointer;

  public RstGen(InputStream is) throws IOException {
    super(is);
    shippointer=source.readInt()-1;
    targetpointer=source.readInt()-1;
    pdatapointer=source.readInt()-1;
    bdatapointer=source.readInt()-1;
    mdatapointer=source.readInt()-1;
    shipxypointer=source.readInt()-1;
    genpointer=source.readInt()-1;
    vcrpointer=source.readInt()-1;
    //report("pointers are: "+shippointer+" "+targetpointer+" "+pdatapointer+
    //   " "+bdatapointer+" "+mdatapointer+" "+shipxypointer+" "+genpointer+
    //   " "+vcrpointer);
  }

  public int getTurnNumber() throws IOException {
    // source.mark(123456789); // never saw a result that big
    source.skipUntil(genpointer);
    source.skip(140);
    int turnnr=source.readShort();
    // source.reset(); // mark() not supported (jdk 1.1.6)
    return turnnr;
  }

  public void generateAll(Universe u,int player) throws IOException {
    // read ships
    source.skipUntil(shippointer);
    ShipGen shipgen=new ShipGen(this);
    shipgen.generateAll(u);
    u.shipgen[player]=shipgen;
    // read targets
    source.skipUntil(targetpointer);
    TargetGen targetgen=new TargetGen(this);
    targetgen.generateAll(u,player);
    // read pdatas
    source.skipUntil(pdatapointer);
    PDataGen pdatagen=new PDataGen(this);
    pdatagen.generateAll(u,player);
    u.pdatagen[player]=pdatagen;
    // read bdatas
    source.skipUntil(bdatapointer);
    BDataGen bdatagen=new BDataGen(this);
    bdatagen.generateAll(u);
    //u.bdatagen[player]=bdatagen;
    // read mdatas
    source.skipUntil(mdatapointer);
    MDataGen mdatagen=new MDataGen(this);
    mdatagen.generateAll(u,player,mdatapointer);
    // read shipxys
    source.skipUntil(shipxypointer);
    ShipXYGen shipxygen=new ShipXYGen(this);
    shipxygen.generateAll(u, player);
    // read gens
    source.skipUntil(genpointer);
    GenGen gengen=new GenGen(this,player,false);
    u.putGen(gengen.generate(),player);
    // read vcrs
    source.skipUntil(vcrpointer);
    VcrGen vcrgen=new VcrGen(this);
    vcrgen.generateAll(u);

    // 'coz a FileStream doesn't have a reference to the File (name),
    // the workaround is getLastOpenedFile() -- very dirty, Kero.
    copyFileToDir(InputFileOpener.getLastOpenedFile().getAbsolutePath(), u.game.workdir.toString()+u.getTurnNumber());
  }
}
